@@ -1,7 +1,5 @@
 package Catmandu::Fix::isbn10;
 
-our $VERSION = '0.12_001';
-
 use Catmandu::Sane;
 use Business::ISBN;
 use Moo;
@@ -14,12 +12,8 @@ with 'Catmandu::Fix::SimpleGetValue';
 sub emit_value {
   my ($self, $var) = @_;
 
-  qq|
-if (is_value(${var}) && length(${var})) {
-  my \$isbn10 = Business::ISBN->new(${var})->as_isbn10;
-  ${var} = \$isbn10 ? \$isbn10->as_string : '';
-}
-|;
+  "${var} = Business::ISBN->new(${var})->as_isbn10->as_string if is_value(${var});";
+
 }
 
 =head1 NAME
