@@ -1,7 +1,5 @@
 package Catmandu::Fix::isbn13;
 
-our $VERSION = '0.12_001';
-
 use Catmandu::Sane;
 use Business::ISBN;
 use Moo;
@@ -14,7 +12,7 @@ with 'Catmandu::Fix::SimpleGetValue';
 sub emit_value {
   my ($self, $var) = @_;
 
-  "${var} = Business::ISBN->new(${var})->as_isbn13->as_string if is_value(${var}) && length(${var});";
+  "${var} = Business::ISBN->new(${var})->as_isbn13->as_string if is_value(${var});";
 
 }
 
