@@ -1,7 +1,5 @@
 package Catmandu::Fix::issn;
 
-our $VERSION = '0.12_001';
-
 use Catmandu::Sane;
 use Business::ISSN;
 use Moo;
@@ -13,7 +11,7 @@ with 'Catmandu::Fix::SimpleGetValue';
 
 sub emit_value {
   my ($self, $var) = @_;
-  "${var} = Business::ISSN->new(${var})->as_string if is_value(${var}) && length(${var});";
+  "${var} = Business::ISSN->new(${var})->as_string if is_value(${var});";
 }
 
 =head1 NAME
