@@ -1,7 +1,7 @@
 package Catmandu::Identifier;
 
 use strict;
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 1;
 __END__
@@ -30,7 +30,9 @@ Catmandu::Identifier - Namespace for handling/fixing identifier, e.g. ISBN, ISSN
 
 =item * L<Catmandu::Fix::isbn13>
 
-=item * L<Catmandu::Fix::isbn_is_valid>
+=item * L<Catmandu::Fix::is_valid_isbn>
+
+=item * L<Catmandu::Fix::is_valid_issn>
 
 =item * L<Catmandu::Fix::issn>
 
@@ -38,7 +40,11 @@ Catmandu::Identifier - Namespace for handling/fixing identifier, e.g. ISBN, ISSN
 
 =head1 AUTHOR
 
-Vitali Peil, C<< <vitali.peil at uni-bielefeld.de> >>
+Vitali Peil
+
+=head2 CONTRIBUTOR
+
+Patrick Hochstenbach
 
 =head1 LICENSE
 
